"""
arifos_core.genius_metrics - BACKWARD COMPATIBILITY SHIM (v42)
Moved to: arifos_core/enforcement/genius_metrics.py
This shim will be removed in v43.0.
"""
from arifos_core.enforcement.genius_metrics import *
